@@ -16,26 +16,37 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.debugger_v2 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
-from google.cloud.debugger_v2.types import data
-from google.cloud.debugger_v2.types import debugger
-from .transports.base import Debugger2Transport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import Debugger2GrpcAsyncIOTransport
+from google.cloud.debugger_v2.types import data, debugger
+
 from .client import Debugger2Client
+from .transports.base import DEFAULT_CLIENT_INFO, Debugger2Transport
+from .transports.grpc_asyncio import Debugger2GrpcAsyncIOTransport
 
 
 class Debugger2AsyncClient:
@@ -163,9 +174,9 @@ class Debugger2AsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, Debugger2Transport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the debugger2 client.
@@ -209,13 +220,13 @@ class Debugger2AsyncClient:
 
     async def set_breakpoint(
         self,
-        request: Union[debugger.SetBreakpointRequest, dict] = None,
+        request: Optional[Union[debugger.SetBreakpointRequest, dict]] = None,
         *,
-        debuggee_id: str = None,
-        breakpoint_: data.Breakpoint = None,
-        client_version: str = None,
+        debuggee_id: Optional[str] = None,
+        breakpoint_: Optional[data.Breakpoint] = None,
+        client_version: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> debugger.SetBreakpointResponse:
         r"""Sets the breakpoint to the debuggee.
@@ -248,7 +259,7 @@ class Debugger2AsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.debugger_v2.types.SetBreakpointRequest, dict]):
+            request (Optional[Union[google.cloud.debugger_v2.types.SetBreakpointRequest, dict]]):
                 The request object. Request to set a breakpoint
             debuggee_id (:class:`str`):
                 Required. ID of the debuggee where
@@ -332,13 +343,13 @@ class Debugger2AsyncClient:
 
     async def get_breakpoint(
         self,
-        request: Union[debugger.GetBreakpointRequest, dict] = None,
+        request: Optional[Union[debugger.GetBreakpointRequest, dict]] = None,
         *,
-        debuggee_id: str = None,
-        breakpoint_id: str = None,
-        client_version: str = None,
+        debuggee_id: Optional[str] = None,
+        breakpoint_id: Optional[str] = None,
+        client_version: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> debugger.GetBreakpointResponse:
         r"""Gets breakpoint information.
@@ -372,7 +383,7 @@ class Debugger2AsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.debugger_v2.types.GetBreakpointRequest, dict]):
+            request (Optional[Union[google.cloud.debugger_v2.types.GetBreakpointRequest, dict]]):
                 The request object. Request to get breakpoint
                 information.
             debuggee_id (:class:`str`):
@@ -472,13 +483,13 @@ class Debugger2AsyncClient:
 
     async def delete_breakpoint(
         self,
-        request: Union[debugger.DeleteBreakpointRequest, dict] = None,
+        request: Optional[Union[debugger.DeleteBreakpointRequest, dict]] = None,
         *,
-        debuggee_id: str = None,
-        breakpoint_id: str = None,
-        client_version: str = None,
+        debuggee_id: Optional[str] = None,
+        breakpoint_id: Optional[str] = None,
+        client_version: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes the breakpoint from the debuggee.
@@ -509,7 +520,7 @@ class Debugger2AsyncClient:
                 await client.delete_breakpoint(request=request)
 
         Args:
-            request (Union[google.cloud.debugger_v2.types.DeleteBreakpointRequest, dict]):
+            request (Optional[Union[google.cloud.debugger_v2.types.DeleteBreakpointRequest, dict]]):
                 The request object. Request to delete a breakpoint.
             debuggee_id (:class:`str`):
                 Required. ID of the debuggee whose
@@ -599,12 +610,12 @@ class Debugger2AsyncClient:
 
     async def list_breakpoints(
         self,
-        request: Union[debugger.ListBreakpointsRequest, dict] = None,
+        request: Optional[Union[debugger.ListBreakpointsRequest, dict]] = None,
         *,
-        debuggee_id: str = None,
-        client_version: str = None,
+        debuggee_id: Optional[str] = None,
+        client_version: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> debugger.ListBreakpointsResponse:
         r"""Lists all breakpoints for the debuggee.
@@ -637,7 +648,7 @@ class Debugger2AsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.debugger_v2.types.ListBreakpointsRequest, dict]):
+            request (Optional[Union[google.cloud.debugger_v2.types.ListBreakpointsRequest, dict]]):
                 The request object. Request to list breakpoints.
             debuggee_id (:class:`str`):
                 Required. ID of the debuggee whose
@@ -722,12 +733,12 @@ class Debugger2AsyncClient:
 
     async def list_debuggees(
         self,
-        request: Union[debugger.ListDebuggeesRequest, dict] = None,
+        request: Optional[Union[debugger.ListDebuggeesRequest, dict]] = None,
         *,
-        project: str = None,
-        client_version: str = None,
+        project: Optional[str] = None,
+        client_version: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> debugger.ListDebuggeesResponse:
         r"""Lists all the debuggees that the user has access to.
@@ -760,7 +771,7 @@ class Debugger2AsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.debugger_v2.types.ListDebuggeesRequest, dict]):
+            request (Optional[Union[google.cloud.debugger_v2.types.ListDebuggeesRequest, dict]]):
                 The request object. Request to list debuggees.
             project (:class:`str`):
                 Required. Project number of a Google
@@ -842,14 +853,9 @@ class Debugger2AsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-debugger-client",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("Debugger2AsyncClient",)
